@@ -146,7 +146,7 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
 
     def get(self):
         # get resolution from xorg.log
-        res = self.Get('install.os_install_x11_resolution_preferred'):
+        res = self.Get('install.os_install_x11_resolution_preferred')
         if res:
             return res
         res = self.framebuffer_resolution()
