@@ -480,7 +480,7 @@ class VariableOsInstallNetRouteData(NetHelper, TableVariable):
         """
         interfaces = self.Get('os_install_net_interfaces')
         if len(interfaces) == 1:
-            wrapper = lambda x: x if x else [x[0],x[1],interfaces[0],x[3]]
+            wrapper = lambda x: x if not x else [x[0],x[1],interfaces[0],x[3]]
         else:
             wrapper = lambda x: x
 
